==> oasis_0.4.5.orig.tar.gz: oasis-0.4.5/src/oasis/OASISBuildSection.mli <==
(******************************************************************************)
(* OASIS: architecture for building OCaml libraries and applications          *)
(*                                                                            *)
(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
(*                                                                            *)
(* This library is free software; you can redistribute it and/or modify it    *)
(* under the terms of the GNU Lesser General Public License as published by   *)
(* the Free Software Foundation; either version 2.1 of the License, or (at    *)
(* your option) any later version, with the OCaml static compilation          *)
(* exception.                                                                 *)
(*                                                                            *)
(* This library is distributed in the hope that it will be useful, but        *)
(* WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY *)
(* or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more         *)
(* details.                                                                   *)
(*                                                                            *)
(* You should have received a copy of the GNU Lesser General Public License   *)
(* along with this library; if not, write to the Free Software Foundation,    *)
(* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
(******************************************************************************)


(** Build section
    @author Sylvain Le Gall
  *)


(** Compute the order of section building, taking into account
    build dependencies between sections. {b Not exported}.
  *)
val build_order: OASISTypes.package -> OASISTypes.section list


(** Compute a map between sections and its build depends.
    The build depends contains only libraries. {b Not exported}.
  *)
val transitive_build_depends:
  OASISTypes.package -> OASISTypes.dependency list OASISSection.MapSection.t

==> oasis_0.4.11.orig.tar.gz: oasis-0.4.11/src/oasis/OASISBuildSection.mli <==
(******************************************************************************)
(* OASIS: architecture for building OCaml libraries and applications          *)
(*                                                                            *)
(* Copyright (C) 2011-2016, Sylvain Le Gall                                   *)
(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
(*                                                                            *)
(* This library is free software; you can redistribute it and/or modify it    *)
(* under the terms of the GNU Lesser General Public License as published by   *)
(* the Free Software Foundation; either version 2.1 of the License, or (at    *)
(* your option) any later version, with the OCaml static compilation          *)
(* exception.                                                                 *)
(*                                                                            *)
(* This library is distributed in the hope that it will be useful, but        *)
(* WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY *)
(* or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more         *)
(* details.                                                                   *)
(*                                                                            *)
(* You should have received a copy of the GNU Lesser General Public License   *)
(* along with this library; if not, write to the Free Software Foundation,    *)
(* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
(******************************************************************************)


(** Build section
    @author Sylvain Le Gall
*)


(** Search a module file. *)
val find_module:
  (string -> bool) ->
  OASISTypes.build_section ->
  OASISUnixPath.unix_filename ->
  [ `No_sources of OASISUnixPath.unix_filename list
  | `Sources of OASISUnixPath.unix_filename * string list ]


(** Compute the order of section building, taking into account
    build dependencies between sections. {b Not exported}.
*)
val build_order: OASISTypes.package -> OASISTypes.section list


(** Compute a map between sections and its build depends.
    The build depends contains only libraries. {b Not exported}.
*)
val transitive_build_depends:
  OASISTypes.package -> OASISTypes.dependency list OASISSection.MapSection.t
